<?php
/**
 * Template for single posts.
 *
 * WordPress identifies this file by its name (which MUST be single.php)
 * and displays it whenever a single post is displayed.
 * 
 * Posts are generally used to present a piece of information that is relevant 
 * during a certain timespan, like a news article. After that time, the contents
 * often lose most of its relevance, aren't updated anymore (even if it means information
 * presented in a post stops to be accurate due to its old age) and kept only for
 * archival purposes.
 * Posts display an author and a post date.
 * 
 * Pages, on the other hand, contain information that is always relevant and should
 * always be kept up to date, see page.php for more.
 *
 * @see https://codex.wordpress.org/Theme_Development#Single_Post_.28single.php.29
 */

get_header();
?>
<main>
    <article>
        <header
        <?php
            echo ' style="background-image:url(\'';
            if ( has_post_thumbnail($post->ID) ) {
                echo wp_get_attachment_url( get_post_thumbnail_id($post->ID) );
            } else {
                echo get_header_image();
            }
            echo '\');"';?> >
            <h1><?php echo get_the_title($post->ID); ?></h1>
        </header>
        <div class="content">
            <?php
                if ( !post_password_required() ) {
                    echo apply_filters('the_content', $post->post_content);
                } else {
                    echo get_the_password_form();
                }
            ?>
        </div>
        <footer>
            <div class="post-meta-author"><?php echo get_the_author_meta('display_name', $post->post_author);?></div>
            <time><?php echo get_the_date();?></time>
        </footer>
    </article>
</main>
<?php get_footer(); ?>
